@@ -238,7 +238,7 @@ class PyModule(pyobjects.PyModule):
         return rope.base.codeanalyze.CachingLogicalLineFinder(self.lines)
 
     def get_name(self):
-        return rope.base.libutils.modname(self.get_resource())
+        return rope.base.libutils.modname(self.resource) if self.resource else ""
 
 
 class PyPackage(pyobjects.PyPackage):
@@ -298,6 +298,9 @@ class PyPackage(pyobjects.PyPackage):
             return self.pycore.project.get_pymodule(init_dot_py)
         return self
 
+    def get_name(self):
+        return rope.base.libutils.modname(self.resource) if self.resource else ""
+
 
 class _AnnAssignVisitor:
     def __init__(self, scope_visitor):
@@ -510,7 +513,7 @@ class _ScopeVisitor(_ExpressionVisitor):
         return self._With(node)
 
     def _excepthandler(self, node):
-        node_name_type = str if pycompat.PY3 else ast.Name
+        node_name_type = str
         if node.name is not None and isinstance(node.name, node_name_type):
             type_node = node.type
             if isinstance(node.type, ast.Tuple) and type_node.elts:
