@@ -33,6 +33,7 @@ import warnings
 from rope.base import change
 from rope.base import exceptions
 from rope.base import fscommands
+from pathlib import Path
 
 
 class Resource:
@@ -42,6 +43,14 @@ class Resource:
         self.project = project
         self._path = path
 
+    def __repr__(self):
+        return '<{}.{} "{}" at {}>'.format(
+            self.__class__.__module__,
+            self.__class__.__name__,
+            self.path,
+            hex(id(self)),
+        )
+
     def move(self, new_location):
         """Move resource to `new_location`"""
         self._perform_change(
@@ -86,6 +95,11 @@ class Resource:
         """Return the file system path of this resource"""
         return self.project._get_resource_path(self.path)
 
+    @property
+    def pathlib(self):
+        """Return the file as a pathlib path."""
+        return Path(self.real_path)
+
     def __eq__(self, obj):
         return self.__class__ == obj.__class__ and self.path == obj.path
 
