@@ -128,17 +128,14 @@ class _SuiteWalker:
     def _TryFinally(self, node):
         proceed_to_except_handler = False
         if len(node.finalbody) == 1:
-            if pycompat.PY2:
-                proceed_to_except_handler = isinstance(node.body[0], ast.TryExcept)
-            elif pycompat.PY3:
-                try:
-                    proceed_to_except_handler = isinstance(
-                        node.handlers[0], ast.ExceptHandler
-                    )
-                except IndexError:
-                    pass
+            try:
+                proceed_to_except_handler = isinstance(
+                    node.handlers[0], ast.ExceptHandler
+                )
+            except IndexError:
+                pass
         if proceed_to_except_handler:
-            self._TryExcept(node if pycompat.PY3 else node.body[0])
+            self._TryExcept(node)
         else:
             self.suites.append(Suite(node.body, node.lineno, self.suite))
         self.suites.append(Suite(node.finalbody, node.lineno, self.suite))
