@@ -1,4 +1,5 @@
 from textwrap import dedent
+
 try:
     import unittest2 as unittest
 except ImportError:
@@ -11,14 +12,14 @@ from rope.base.builtins import Dict
 
 class BuiltinTypesTest(unittest.TestCase):
     def setUp(self):
-        super(BuiltinTypesTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
         self.mod = testutils.create_module(self.project, "mod")
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(BuiltinTypesTest, self).tearDown()
+        super().tearDown()
 
     def test_simple_case(self):
         self.mod.write("l = []\n")
@@ -26,87 +27,75 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertTrue("append" in pymod["l"].get_object())
 
     def test_holding_type_information(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                a_var = l.pop()
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            a_var = l.pop()
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_get_items(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    def __getitem__(self, i):
-                        return C()
-                c = C()
-                a_var = c[0]"""
-            )
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                def __getitem__(self, i):
+                    return C()
+            c = C()
+            a_var = c[0]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_get_items_for_lists(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                a_var = l[0]
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            a_var = l[0]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_get_items_from_slices(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                a_var = l[:].pop()
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            a_var = l[:].pop()
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_simple_for_loops(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                for c in l:
-                    a_var = c
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            for c in l:
+                a_var = c
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_definition_location_for_loop_variables(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                for c in l:
-                    pass
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            for c in l:
+                pass
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_var = pymod["c"]
         self.assertEqual((pymod, 4), c_var.get_definition_location())
@@ -117,140 +106,122 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertTrue("get" in pymod["d"].get_object())
 
     def test_get_item_for_dicts(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                d = {1: C()}
-                a_var = d[1]
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            d = {1: C()}
+            a_var = d[1]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_dict_function_parent(self):
-        self.mod.write(
-            dedent("""\
-                d = {1: 2}
-                a_var = d.keys()"""
-            )
-        )
+        self.mod.write(dedent("""\
+            d = {1: 2}
+            a_var = d.keys()
+        """))
         pymod = self.project.get_pymodule(self.mod)
         a_var = pymod["d"].get_object()["keys"].get_object()
         self.assertEqual(type(a_var.parent), Dict)
 
     def test_popping_dicts(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                d = {1: C()}
-                a_var = d.pop(1)
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            d = {1: C()}
+            a_var = d.pop(1)
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_getting_keys_from_dicts(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                d = {C1(): C2()}
-                for c in d.keys():
-                    a_var = c
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            d = {C1(): C2()}
+            for c in d.keys():
+                a_var = c
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C1"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_getting_values_from_dicts(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                d = {C1(): C2()}
-                for c in d.values():
-                    a_var = c
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            d = {C1(): C2()}
+            for c in d.values():
+                a_var = c
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C2"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_getting_iterkeys_from_dicts(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                d = {C1(): C2()}
-                for c in d.keys():
-                    a_var = c
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            d = {C1(): C2()}
+            for c in d.keys():
+                a_var = c
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C1"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_getting_itervalues_from_dicts(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                d = {C1(): C2()}
-                for c in d.values():
-                    a_var = c
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            d = {C1(): C2()}
+            for c in d.values():
+                a_var = c
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C2"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_using_copy_for_dicts(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                d = {C1(): C2()}
-                for c in d.copy():
-                    a_var = c
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            d = {C1(): C2()}
+            for c in d.copy():
+                a_var = c
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C1"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_tuple_assignments_for_items(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                d = {C1(): C2()}
-                key, value = d.items()[0]
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            d = {C1(): C2()}
+            key, value = d.items()[0]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c1_class = pymod["C1"].get_object()
         c2_class = pymod["C2"].get_object()
@@ -260,14 +231,12 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEqual(c2_class, value.get_type())
 
     def test_tuple_assignment_for_lists(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C(), C()]
-                a, b = l
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C(), C()]
+            a, b = l
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a"].get_object()
@@ -276,18 +245,16 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEqual(c_class, b_var.get_type())
 
     def test_tuple_assignments_for_iteritems_in_fors(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                d = {C1(): C2()}
-                for x, y in d.items():
-                    a = x;
-                    b = y
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            d = {C1(): C2()}
+            for x, y in d.items():
+                a = x;
+                b = y
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c1_class = pymod["C1"].get_object()
         c2_class = pymod["C2"].get_object()
@@ -297,15 +264,13 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEqual(c2_class, b_var.get_type())
 
     def test_simple_tuple_assignments(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                a, b = C1(), C2()
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            a, b = C1(), C2()
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c1_class = pymod["C1"].get_object()
         c2_class = pymod["C2"].get_object()
@@ -315,13 +280,11 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEqual(c2_class, b_var.get_type())
 
     def test_overriding_builtin_names(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                list = C
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            list = C
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         list_var = pymod["list"].get_object()
@@ -338,62 +301,54 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertTrue("add" in pymod["s"].get_object())
 
     def test_making_lists_using_the_passed_argument_to_init(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l1 = [C()]
-                l2 = list(l1)
-                a_var = l2.pop()"""
-            )
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l1 = [C()]
+            l2 = list(l1)
+            a_var = l2.pop()
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_making_tuples_using_the_passed_argument_to_init(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l1 = [C()]
-                l2 = tuple(l1)
-                a_var = l2[0]"""
-            )
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l1 = [C()]
+            l2 = tuple(l1)
+            a_var = l2[0]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_making_sets_using_the_passed_argument_to_init(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l1 = [C()]
-                l2 = set(l1)
-                a_var = l2.pop()"""
-            )
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l1 = [C()]
+            l2 = set(l1)
+            a_var = l2.pop()
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_making_dicts_using_the_passed_argument_to_init(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                l1 = [(C1(), C2())]
-                l2 = dict(l1)
-                a, b = l2.items()[0]"""
-            )
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            l1 = [(C1(), C2())]
+            l2 = dict(l1)
+            a, b = l2.items()[0]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c1_class = pymod["C1"].get_object()
         c2_class = pymod["C2"].get_object()
@@ -409,60 +364,52 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertTrue("append" in l)
 
     def test_reversed_builtin_function(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                for x in reversed(l):
-                    a_var = x
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            for x in reversed(l):
+                a_var = x
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_sorted_builtin_function(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                a_var = sorted(l).pop()
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            a_var = sorted(l).pop()
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_super_builtin_function(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                class A(object):
-                    def a_f(self):
-                        return C()
-                class B(A):
-                    def b_f(self):
-                        return super(B, self).a_f()
-                a_var = B.b_f()
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            class A(object):
+                def a_f(self):
+                    return C()
+            class B(A):
+                def b_f(self):
+                    return super(B, self).a_f()
+            a_var = B.b_f()
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
         self.assertEqual(c_class, a_var.get_type())
 
     def test_file_builtin_type(self):
-        self.mod.write(
-            dedent("""\
-                for line in open("file.txt"):
-                    a_var = line
-            """)
-        )
+        self.mod.write(dedent("""\
+            for line in open("file.txt"):
+                a_var = line
+        """))
         pymod = self.project.get_pymodule(self.mod)
         a_var = pymod["a_var"].get_object()
         self.assertTrue(isinstance(a_var.get_type(), builtins.Str))
@@ -494,17 +441,15 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertTrue(a_var is not None)
 
     def test_builtin_zip_function(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                c1_list = [C1()]
-                c2_list = [C2()]
-                a, b = zip(c1_list, c2_list)[0]"""
-            )
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            c1_list = [C1()]
+            c2_list = [C2()]
+            a, b = zip(c1_list, c2_list)[0]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c1_class = pymod["C1"].get_object()
         c2_class = pymod["C2"].get_object()
@@ -514,17 +459,15 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEqual(c2_class, b_var.get_type())
 
     def test_builtin_zip_function_with_more_than_two_args(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                class C2(object):
-                    pass
-                c1_list = [C1()]
-                c2_list = [C2()]
-                a, b, c = zip(c1_list, c2_list, c1_list)[0]"""
-            )
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            class C2(object):
+                pass
+            c1_list = [C1()]
+            c2_list = [C2()]
+            a, b, c = zip(c1_list, c2_list, c1_list)[0]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c1_class = pymod["C1"].get_object()
         c2_class = pymod["C2"].get_object()
@@ -536,14 +479,12 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEqual(c1_class, c_var.get_type())
 
     def test_wrong_arguments_to_zip_function(self):
-        self.mod.write(
-            dedent("""\
-                class C1(object):
-                    pass
-                c1_list = [C1()]
-                a, b = zip(c1_list, 1)[0]"""
-            )
-        )
+        self.mod.write(dedent("""\
+            class C1(object):
+                pass
+            c1_list = [C1()]
+            a, b = zip(c1_list, 1)[0]
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c1_class = pymod["C1"].get_object()
         a_var = pymod["a"].get_object()
@@ -551,15 +492,13 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEqual(c1_class, a_var.get_type())
 
     def test_enumerate_builtin_function(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                for i, x in enumerate(l):
-                    a_var = x
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            for i, x in enumerate(l):
+                a_var = x
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
@@ -572,12 +511,10 @@ class BuiltinTypesTest(unittest.TestCase):
         )
 
     def test_star_args_and_double_star_args(self):
-        self.mod.write(
-            dedent("""\
-                def func(p, *args, **kwds):
-                    pass
-            """)
-        )
+        self.mod.write(dedent("""\
+            def func(p, *args, **kwds):
+                pass
+        """))
         pymod = self.project.get_pymodule(self.mod)
         func_scope = pymod["func"].get_object().get_scope()
         args = func_scope["args"].get_object()
@@ -598,15 +535,13 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertTrue(isinstance(a_var.get_type(), builtins.Iterator))
 
     def test_iter_builtin_function(self):
-        self.mod.write(
-            dedent("""\
-                class C(object):
-                    pass
-                l = [C()]
-                for c in iter(l):
-                    a_var = c
-            """)
-        )
+        self.mod.write(dedent("""\
+            class C(object):
+                pass
+            l = [C()]
+            for c in iter(l):
+                a_var = c
+        """))
         pymod = self.project.get_pymodule(self.mod)
         c_class = pymod["C"].get_object()
         a_var = pymod["a_var"].get_object()
@@ -696,7 +631,7 @@ class BuiltinTypesTest(unittest.TestCase):
 
 class BuiltinModulesTest(unittest.TestCase):
     def setUp(self):
-        super(BuiltinModulesTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project(
             extension_modules=["time", "invalid", "invalid.sub"]
         )
@@ -704,7 +639,7 @@ class BuiltinModulesTest(unittest.TestCase):
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(BuiltinModulesTest, self).tearDown()
+        super().tearDown()
 
     def test_simple_case(self):
         self.mod.write("import time")
@@ -727,12 +662,10 @@ class BuiltinModulesTest(unittest.TestCase):
         pymod["invalid"].get_object()
 
     def test_nonexistent_modules_2(self):
-        self.mod.write(
-            dedent("""\
-                import invalid
-                import invalid.sub"""
-            )
-        )
+        self.mod.write(dedent("""\
+            import invalid
+            import invalid.sub
+        """))
         pymod = self.project.get_pymodule(self.mod)
         invalid = pymod["invalid"].get_object()
         self.assertTrue("sub" in invalid)
