@@ -346,7 +346,7 @@ class WordRangeFinderTest(unittest.TestCase):
         result = self._find_primary(code, len(code) - 1)
         self.assertEqual("(4 + 1).x", result)
 
-    # XXX: cancatenated string literals
+    # XXX: concatenated string literals
     def xxx_test_getting_primary_cancatenating_strs(self):
         code = 's = "a"\n"b" "c"\n'
         result = self._find_primary(code, len(code) - 2)
@@ -612,12 +612,12 @@ class WordRangeFinderTest(unittest.TestCase):
 
 class ScopeNameFinderTest(unittest.TestCase):
     def setUp(self):
-        super(ScopeNameFinderTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(ScopeNameFinderTest, self).tearDown()
+        super().tearDown()
 
     # FIXME: in normal scopes the interpreter raises `UnboundLocalName`
     # exception, but not in class bodies
