@@ -35,8 +35,6 @@ def typing_path():
     yield pathlib.Path(typing.__file__)
 
 
-
-
 @pytest.fixture
 def build_env_path():
     from build import env
@@ -54,7 +52,7 @@ def build_path():
 
 
 @pytest.fixture
-def zlib_path():
-    import zlib
+def compiled_lib():
+    import _sqlite3
 
-    yield pathlib.Path(zlib.__file__)
+    yield "_sqlite3", pathlib.Path(_sqlite3.__file__)
