@@ -1,5 +1,3 @@
-# coding: utf-8
-
 import os.path
 from textwrap import dedent
 
@@ -29,12 +27,12 @@ except NameError:
 
 class CodeAssistTest(unittest.TestCase):
     def setUp(self):
-        super(CodeAssistTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(CodeAssistTest, self).tearDown()
+        super().tearDown()
 
     def _assist(self, code, offset=None, **args):
         if offset is None:
@@ -619,17 +617,15 @@ class CodeAssistTest(unittest.TestCase):
         self.assertEqual((None, 3), result)
 
     def test_get_definition_location_false_triple_quoted_string(self):
-        code = dedent(
-            dedent('''\
-                def foo():
-                    a = 0
-                    p = "foo"""
+        code = dedent('''\
+            def foo():
+                a = 0
+                p = "foo"""
 
-                def bar():
-                    a = 1
-                    a += 1
-            ''')
-        )
+            def bar():
+                a = 1
+                a += 1
+        ''')
         result = get_definition_location(self.project, code, code.index("a += 1"))
         self.assertEqual((None, 6), result)
 
@@ -739,7 +735,7 @@ class CodeAssistTest(unittest.TestCase):
               u"юникод-объект"''')
         doc = get_doc(self.project, src, src.index("foo") + 1)
         self.assertTrue(isinstance(doc, unicode))
-        self.assertTrue(u"юникод-объект" in doc)
+        self.assertTrue("юникод-объект" in doc)
 
     def test_get_pydoc_utf8_bytestring(self):
         src = dedent('''\
@@ -748,7 +744,7 @@ class CodeAssistTest(unittest.TestCase):
               "байтстринг"''')
         doc = get_doc(self.project, src, src.index("foo") + 1)
         self.assertTrue(isinstance(doc, unicode))
-        self.assertTrue(u"байтстринг" in doc)
+        self.assertTrue("байтстринг" in doc)
 
     def test_get_pydoc_for_functions(self):
         src = dedent('''\
@@ -1330,7 +1326,7 @@ class CodeAssistTest(unittest.TestCase):
 
 class CodeAssistInProjectsTest(unittest.TestCase):
     def setUp(self):
-        super(CodeAssistInProjectsTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
         samplemod = testutils.create_module(self.project, "samplemod")
@@ -1501,12 +1497,10 @@ class CodeAssistInProjectsTest(unittest.TestCase):
         pkg = testutils.create_package(self.project, "pkg")
         mod1 = testutils.create_module(self.project, "mod1", pkg)
         mod2 = testutils.create_module(self.project, "mod2", pkg)
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         code = dedent("""\
             import mod1
             mod1.""")
@@ -1517,12 +1511,10 @@ class CodeAssistInProjectsTest(unittest.TestCase):
         pkg = testutils.create_package(self.project, "pkg")
         mod1 = testutils.create_module(self.project, "mod1", pkg)
         mod2 = testutils.create_module(self.project, "mod2", pkg)
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         code = dedent("""\
             import mod1
             mod1.a_func
@@ -1539,13 +1531,11 @@ class CodeAssistInProjectsTest(unittest.TestCase):
         pkg = testutils.create_package(self.project, "pkg")
         mod1 = testutils.create_module(self.project, "mod1", pkg)
         mod2 = testutils.create_module(self.project, "mod2", pkg)
-        mod1.write(
-            dedent('''\
-                def a_func():
-                    """hey"""
-                    pass
-            ''')
-        )
+        mod1.write(dedent('''\
+            def a_func():
+                """hey"""
+                pass
+        '''))
         code = dedent("""\
             import mod1
             mod1.a_func
@@ -1555,12 +1545,10 @@ class CodeAssistInProjectsTest(unittest.TestCase):
 
     def test_get_doc_on_from_import_module(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent('''\
-                """mod1 docs"""
-                var = 1
-            ''')
-        )
+        mod1.write(dedent('''\
+            """mod1 docs"""
+            var = 1
+        '''))
         code = "from mod1 import var\n"
         result = get_doc(self.project, code, code.index("mod1"))
         result.index("mod1 docs")
