@@ -12,13 +12,13 @@ from ropetest import testutils
 
 class FindErrorsTest(unittest.TestCase):
     def setUp(self):
-        super(FindErrorsTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.mod = self.project.root.create_file("mod.py")
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(FindErrorsTest, self).tearDown()
+        super().tearDown()
 
     def test_unresolved_variables(self):
         self.mod.write("print(var)\n")
@@ -27,12 +27,10 @@ class FindErrorsTest(unittest.TestCase):
         self.assertEqual(1, result[0].lineno)
 
     def test_defined_later(self):
-        self.mod.write(
-            dedent("""\
-                print(var)
-                var = 1
-            """)
-        )
+        self.mod.write(dedent("""\
+            print(var)
+            var = 1
+        """))
         result = finderrors.find_errors(self.project, self.mod)
         self.assertEqual(1, len(result))
         self.assertEqual(1, result[0].lineno)
