@@ -12,7 +12,7 @@ from ropetest import testutils
 
 class GenerateTest(unittest.TestCase):
     def setUp(self):
-        super(GenerateTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
         self.mod = testutils.create_module(self.project, "mod1")
@@ -21,7 +21,7 @@ class GenerateTest(unittest.TestCase):
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(GenerateTest, self).tearDown()
+        super().tearDown()
 
     def _get_generate(self, offset):
         return generate.GenerateVariable(self.project, self.mod, offset)
@@ -130,9 +130,9 @@ class GenerateTest(unittest.TestCase):
 
                     attr = None
                 c = C()
-                a_var = c.attr"""
-            ),
-            self.mod.read(),)
+                a_var = c.attr"""),
+            self.mod.read(),
+        )
 
     def test_generating_variable_in_classes_removing_pass(self):
         code = dedent("""\
@@ -149,9 +149,9 @@ class GenerateTest(unittest.TestCase):
 
                     attr = None
                 c = C()
-                a_var = c.attr"""
-            ),
-            self.mod.read(),)
+                a_var = c.attr"""),
+            self.mod.read(),
+        )
 
     def test_generating_variable_in_packages(self):
         code = "import pkg\na = pkg.a\n"
@@ -368,12 +368,10 @@ class GenerateTest(unittest.TestCase):
         )
 
     def test_generating_calls_in_other_modules(self):
-        self.mod2.write(
-            dedent("""\
-                class C(object):
-                    pass
-            """)
-        )
+        self.mod2.write(dedent("""\
+            class C(object):
+                pass
+        """))
         code = dedent("""\
             import mod2
             c = mod2.C()
