@@ -13,12 +13,12 @@ from ropetest import testutils
 
 class ObjectInferTest(unittest.TestCase):
     def setUp(self):
-        super(ObjectInferTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(ObjectInferTest, self).tearDown()
+        super().tearDown()
 
     def test_simple_type_inferencing(self):
         code = dedent("""\
@@ -306,14 +306,12 @@ class ObjectInferTest(unittest.TestCase):
 
     def test_handling_generator_functions_for_strs(self):
         mod = testutils.create_module(self.project, "mod")
-        mod.write(
-            dedent("""\
-                def f():
-                    yield ""
-                for s in f():
-                    a_var = s
-            """)
-        )
+        mod.write(dedent("""\
+            def f():
+                yield ""
+            for s in f():
+                a_var = s
+        """))
         pymod = self.project.get_pymodule(mod)
         a_var = pymod["a_var"].get_object()
         self.assertTrue(isinstance(a_var.get_type(), rope.base.builtins.Str))
