@@ -18,13 +18,13 @@ from ropetest import testutils
 
 class PyCoreTest(unittest.TestCase):
     def setUp(self):
-        super(PyCoreTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(PyCoreTest, self).tearDown()
+        super().tearDown()
 
     def test_simple_module(self):
         testutils.create_module(self.project, "mod")
@@ -49,24 +49,20 @@ class PyCoreTest(unittest.TestCase):
 
     def test_simple_class(self):
         mod = testutils.create_module(self.project, "mod")
-        mod.write(
-            dedent("""\
-                class SampleClass(object):
-                    pass
-            """)
-        )
+        mod.write(dedent("""\
+            class SampleClass(object):
+                pass
+        """))
         mod_element = self.project.get_module("mod")
         result = mod_element["SampleClass"].get_object()
         self.assertEqual(get_base_type("Type"), result.get_type())
 
     def test_simple_function(self):
         mod = testutils.create_module(self.project, "mod")
-        mod.write(
-            dedent("""\
-                def sample_function():
-                    pass
-            """)
-        )
+        mod.write(dedent("""\
+            def sample_function():
+                pass
+        """))
         mod_element = self.project.get_module("mod")
         result = mod_element["sample_function"].get_object()
         self.assertEqual(get_base_type("Function"), result.get_type())
@@ -102,25 +98,21 @@ class PyCoreTest(unittest.TestCase):
 
     def test_class_variables(self):
         mod = testutils.create_module(self.project, "mod")
-        mod.write(
-            dedent("""\
-                class SampleClass(object):
-                    var = 10
-            """)
-        )
+        mod.write(dedent("""\
+            class SampleClass(object):
+                var = 10
+        """))
         mod_element = self.project.get_module("mod")
         sample_class = mod_element["SampleClass"].get_object()
         var = sample_class["var"]  # noqa
 
     def test_class_attributes_set_in_init(self):
         mod = testutils.create_module(self.project, "mod")
-        mod.write(
-            dedent("""\
-                class C(object):
-                    def __init__(self):
-                        self.var = 20
-            """)
-        )
+        mod.write(dedent("""\
+            class C(object):
+                def __init__(self):
+                    self.var = 20
+        """))
         mod_element = self.project.get_module("mod")
         sample_class = mod_element["C"].get_object()
         var = sample_class["var"]  # noqa
@@ -185,7 +177,7 @@ class PyCoreTest(unittest.TestCase):
 
     def test_get_string_module_with_extra_spaces(self):
         code = "a = 10\n    "
-        mod = libutils.get_string_module(self.project, code) # noqa
+        mod = libutils.get_string_module(self.project, code)  # noqa
 
     def test_parameter_info_for_functions(self):
         code = dedent("""\
@@ -409,13 +401,11 @@ class PyCoreTest(unittest.TestCase):
 
     def test_get_pyname_definition_location_imports(self):
         module_resource = testutils.create_module(self.project, "mod")
-        module_resource.write(
-            dedent("""\
+        module_resource.write(dedent("""\
 
-                def a_func():
-                    pass
-            """)
-        )
+            def a_func():
+                pass
+        """))
         imported_module = self.project.get_module("mod")
         code = dedent("""\
             from mod import a_func
@@ -512,7 +502,7 @@ class PyCoreTest(unittest.TestCase):
 
     def test_file_encoding_reading(self):
         contents = (
-            u"# -*- coding: utf-8 -*-\n" + u"#\N{LATIN SMALL LETTER I WITH DIAERESIS}\n"
+            "# -*- coding: utf-8 -*-\n" + "#\N{LATIN SMALL LETTER I WITH DIAERESIS}\n"
         )
         mod = testutils.create_module(self.project, "mod")
         mod.write(contents)
@@ -779,12 +769,10 @@ class PyCoreTest(unittest.TestCase):
 
     def test_pyobject_equality_should_compare_types(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                var1 = ""
-                var2 = ""
-            """)
-        )
+        mod1.write(dedent("""\
+            var1 = ""
+            var2 = ""
+        """))
         pymod1 = self.pycore.resource_to_pyobject(mod1)
         self.assertEqual(pymod1["var1"].get_object(), pymod1["var2"].get_object())
 
@@ -905,31 +893,25 @@ class PyCoreInProjectsTest(unittest.TestCase):
     def test_circular_imports2(self):
         mod1 = testutils.create_module(self.project, "mod1")
         mod2 = testutils.create_module(self.project, "mod2")
-        mod1.write(
-            dedent("""\
-                from mod2 import Sample2
-                class Sample1(object):
-                    pass
-            """)
-        )
-        mod2.write(
-            dedent("""\
-                from mod1 import Sample1
-                class Sample2(object):
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            from mod2 import Sample2
+            class Sample1(object):
+                pass
+        """))
+        mod2.write(dedent("""\
+            from mod1 import Sample1
+            class Sample2(object):
+                pass
+        """))
         self.project.get_module("mod1").get_attributes()
 
     def test_multi_dot_imports(self):
         pkg = testutils.create_package(self.project, "pkg")
         pkg_mod = testutils.create_module(self.project, "mod", pkg)
-        pkg_mod.write(
-            dedent("""\
-                def sample_func():
-                    pass
-            """)
-        )
+        pkg_mod.write(dedent("""\
+            def sample_func():
+                pass
+        """))
         code = "import pkg.mod\n"
         mod = libutils.get_string_module(self.project, code)
         self.assertTrue("pkg" in mod)
@@ -966,12 +948,10 @@ class PyCoreInProjectsTest(unittest.TestCase):
     def test_multi_dot_imports_as(self):
         pkg = testutils.create_package(self.project, "pkg")
         mod1 = testutils.create_module(self.project, "mod1", pkg)
-        mod1.write(
-            dedent("""\
-                def f():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def f():
+                pass
+        """))
         code = "import pkg.mod1 as mod1\n"
         mod = libutils.get_string_module(self.project, code)
         module = mod["mod1"].get_object()
@@ -1128,12 +1108,10 @@ class PyCoreInProjectsTest(unittest.TestCase):
         pkg = testutils.create_package(self.project, "pkg")
         mod1 = testutils.create_module(self.project, "mod1", pkg)
         mod2 = testutils.create_module(self.project, "mod2", pkg)
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         mod2.write("from mod1 import a_func\n")
         mod1_object = self.pycore.resource_to_pyobject(mod1)
         mod2_object = self.pycore.resource_to_pyobject(mod2)
@@ -1174,12 +1152,10 @@ class PyCoreInProjectsTest(unittest.TestCase):
         pkg = testutils.create_package(self.project, "pkg")
         mod1 = testutils.create_module(self.project, "mod1")
         mod2 = testutils.create_module(self.project, "mod2", pkg)
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         mod2.write("from ..mod1 import a_func\n")
         mod1_object = self.pycore.resource_to_pyobject(mod1)
         mod2_object = self.pycore.resource_to_pyobject(mod2)
@@ -1190,18 +1166,14 @@ class PyCoreInProjectsTest(unittest.TestCase):
     def test_invalidating_cache_for_from_imports_after_resource_change(self):
         mod1 = testutils.create_module(self.project, "mod1")
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                def a_func():
-                    print(1)
-            """)
-        )
-        mod1.write(
-            dedent("""\
-                from mod2 import a_func
-                a_func()
-            """)
-        )
+        mod2.write(dedent("""\
+            def a_func():
+                print(1)
+        """))
+        mod1.write(dedent("""\
+            from mod2 import a_func
+            a_func()
+        """))
 
         pymod1 = self.project.get_module("mod1")
         pymod2 = self.project.get_module("mod2")
@@ -1213,31 +1185,25 @@ class PyCoreInProjectsTest(unittest.TestCase):
     def test_invalidating_superclasses_after_change(self):
         mod1 = testutils.create_module(self.project, "mod1")
         mod2 = testutils.create_module(self.project, "mod2")
-        mod1.write(
-            dedent("""\
-                class A(object):
-                    def func1(self):
-                        pass
-            """)
-        )
-        mod2.write(
-            dedent("""\
-                import mod1
-                class B(mod1.A):
+        mod1.write(dedent("""\
+            class A(object):
+                def func1(self):
                     pass
-            """)
-        )
+        """))
+        mod2.write(dedent("""\
+            import mod1
+            class B(mod1.A):
+                pass
+        """))
 
         b_class = self.project.get_module("mod2")["B"].get_object()
         self.assertTrue("func1" in b_class)
 
-        mod1.write(
-            dedent("""\
-                class A(object):
-                    def func2(self):
-                        pass
-            """)
-        )
+        mod1.write(dedent("""\
+            class A(object):
+                def func2(self):
+                    pass
+        """))
         self.assertTrue("func2" in b_class)
 
     def test_caching_pymodule_with_syntax_errors(self):
@@ -1246,7 +1212,8 @@ class PyCoreInProjectsTest(unittest.TestCase):
         self.project.pycore._init_automatic_soa()
         source = dedent("""\
             import sys
-            ab cd""")
+            ab cd
+        """)
         mod = testutils.create_module(self.project, "mod")
         mod.write(source)
         from rope.contrib import fixsyntax
@@ -1290,13 +1257,13 @@ class TextChangeDetectorTest(unittest.TestCase):
 
 class PyCoreProjectConfigsTest(unittest.TestCase):
     def setUp(self):
-        super(PyCoreProjectConfigsTest, self).setUp()
+        super().setUp()
         self.project = None
 
     def tearDown(self):
         if self.project:
             testutils.remove_project(self.project)
-        super(PyCoreProjectConfigsTest, self).tearDown()
+        super().tearDown()
 
     def test_python_files_config(self):
         self.project = testutils.sample_project(python_files=["myscript"])
