@@ -28,14 +28,14 @@ from ropetest.refactor import change_signature_test, similarfindertest
 
 class MethodObjectTest(unittest.TestCase):
     def setUp(self):
-        super(MethodObjectTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
         self.mod = testutils.create_module(self.project, "mod")
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(MethodObjectTest, self).tearDown()
+        super().tearDown()
 
     def test_empty_method(self):
         code = dedent("""\
@@ -241,13 +241,13 @@ class MethodObjectTest(unittest.TestCase):
 
 class IntroduceFactoryTest(unittest.TestCase):
     def setUp(self):
-        super(IntroduceFactoryTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(IntroduceFactoryTest, self).tearDown()
+        super().tearDown()
 
     def _introduce_factory(self, resource, offset, *args, **kwds):
         factory_introducer = IntroduceFactory(self.project, resource, offset)
@@ -607,7 +607,7 @@ class IntroduceFactoryTest(unittest.TestCase):
 
 class EncapsulateFieldTest(unittest.TestCase):
     def setUp(self):
-        super(EncapsulateFieldTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
         self.mod = testutils.create_module(self.project, "mod")
@@ -628,7 +628,7 @@ class EncapsulateFieldTest(unittest.TestCase):
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(EncapsulateFieldTest, self).tearDown()
+        super().tearDown()
 
     def _encapsulate(self, resource, offset, **args):
         changes = EncapsulateField(self.project, resource, offset).get_changes(**args)
@@ -852,14 +852,14 @@ class EncapsulateFieldTest(unittest.TestCase):
 
 class LocalToFieldTest(unittest.TestCase):
     def setUp(self):
-        super(LocalToFieldTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
         self.mod = testutils.create_module(self.project, "mod")
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(LocalToFieldTest, self).tearDown()
+        super().tearDown()
 
     def _perform_convert_local_variable_to_field(self, resource, offset):
         changes = LocalToField(self.project, resource, offset).get_changes()
@@ -944,14 +944,14 @@ class LocalToFieldTest(unittest.TestCase):
 
 class IntroduceParameterTest(unittest.TestCase):
     def setUp(self):
-        super(IntroduceParameterTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
         self.pycore = self.project.pycore
         self.mod = testutils.create_module(self.project, "mod")
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(IntroduceParameterTest, self).tearDown()
+        super().tearDown()
 
     def _introduce_parameter(self, offset, name):
         rope.refactor.introduce_parameter.IntroduceParameter(
@@ -1042,7 +1042,7 @@ class IntroduceParameterTest(unittest.TestCase):
         self.assertEqual(expected, self.mod.read())
 
 
-class _MockTaskObserver(object):
+class _MockTaskObserver:
     def __init__(self):
         self.called = 0
 
@@ -1122,7 +1122,14 @@ class TaskHandleTest(unittest.TestCase):
     def test_getting_job_name(self):
         handle = rope.base.taskhandle.TaskHandle()
         jobs = handle.create_jobset(name="test job set", count=1)
+        # recommended name/job_name attribute
+        self.assertEqual("test job set", jobs.name)
+        self.assertEqual(None, jobs.job_name)
+        # deprecated getters
         self.assertEqual("test job set", jobs.get_name())
         self.assertEqual(None, jobs.get_active_job_name())
         jobs.started_job("job1")
+        # recommended name/job_name attribute
+        self.assertEqual("test job set", jobs.get_name())
+        # deprecated getters
         self.assertEqual("job1", jobs.get_active_job_name())
