@@ -1,4 +1,5 @@
 from textwrap import dedent
+
 try:
     import unittest2 as unittest
 except ImportError:
@@ -10,7 +11,7 @@ from ropetest import testutils
 
 class MultiProjectRefactoringTest(unittest.TestCase):
     def setUp(self):
-        super(MultiProjectRefactoringTest, self).setUp()
+        super().setUp()
         self.project1 = testutils.sample_project(foldername="testproject1")
         self.project2 = testutils.sample_project(foldername="testproject2")
         self.mod1 = self.project1.root.create_file("mod1.py")
@@ -20,7 +21,7 @@ class MultiProjectRefactoringTest(unittest.TestCase):
     def tearDown(self):
         testutils.remove_project(self.project1)
         testutils.remove_project(self.project2)
-        super(MultiProjectRefactoringTest, self).tearDown()
+        super().tearDown()
 
     def test_trivial_rename(self):
         self.mod1.write("var = 1\n")
@@ -31,12 +32,10 @@ class MultiProjectRefactoringTest(unittest.TestCase):
 
     def test_rename(self):
         self.mod1.write("var = 1\n")
-        self.mod2.write(
-            dedent("""\
-                import mod1
-                myvar = mod1.var
-            """)
-        )
+        self.mod2.write(dedent("""\
+            import mod1
+            myvar = mod1.var
+        """))
         refactoring = multiproject.MultiProjectRefactoring(
             rename.Rename, [self.project2]
         )
@@ -52,18 +51,14 @@ class MultiProjectRefactoringTest(unittest.TestCase):
         )
 
     def test_move(self):
-        self.mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
-        self.mod2.write(
-            dedent("""\
-                import mod1
-                myvar = mod1.a_func()
-            """)
-        )
+        self.mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
+        self.mod2.write(dedent("""\
+            import mod1
+            myvar = mod1.a_func()
+        """))
         refactoring = multiproject.MultiProjectRefactoring(
             move.create_move, [self.project2]
         )
@@ -88,12 +83,10 @@ class MultiProjectRefactoringTest(unittest.TestCase):
     def test_rename_from_the_project_not_containing_the_change(self):
         self.project2.get_prefs().add("python_path", self.project1.address)
         self.mod1.write("var = 1\n")
-        self.mod2.write(
-            dedent("""\
-                import mod1
-                myvar = mod1.var
-            """)
-        )
+        self.mod2.write(dedent("""\
+            import mod1
+            myvar = mod1.var
+        """))
         refactoring = multiproject.MultiProjectRefactoring(
             rename.Rename, [self.project1]
         )
