@@ -21,10 +21,10 @@ Bytes = "Bytes" if (3, 0) <= sys.version_info <= (3, 8) else "Str"
 
 class PatchedASTTest(unittest.TestCase):
     def setUp(self):
-        super(PatchedASTTest, self).setUp()
+        super().setUp()
 
     def tearDown(self):
-        super(PatchedASTTest, self).tearDown()
+        super().tearDown()
 
     def assert_single_case_match_block(self, checker, match_type):
         checker.check_children("Match", [
@@ -66,22 +66,18 @@ class PatchedASTTest(unittest.TestCase):
         source = "a = -10\n"
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        start = source.index("-10")
-        end = start + 3
+        start = source.index("-10") + 1
+        end = start + 2
         # Python 3 parses as UnaryOp(op=USub(), operand=Num(n=10))
-        if pycompat.PY3:
-            start += 1
         checker.check_region("Num", start, end)
 
     def test_scientific_integer_literals_and_region(self):
         source = "a = -1.0e-3\n"
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        start = source.index("-1.0e-3")
-        end = start + 7
+        start = source.index("-1.0e-3") + 1
+        end = start + 6
         # Python 3 parses as UnaryOp(op=USub(), operand=Num(n=10))
-        if pycompat.PY3:
-            start += 1
         checker.check_region("Num", start, end)
 
     def test_hex_integer_literals_and_region(self):
@@ -103,11 +99,9 @@ class PatchedASTTest(unittest.TestCase):
         source = "a = -0125e1\n"
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        start = source.index("-0125e1")
-        end = start + 7
+        start = source.index("-0125e1") + 1
+        end = start + 6
         # Python 3 parses as UnaryOp(op=USub(), operand=Num(n=10))
-        if pycompat.PY3:
-            start += 1
         checker.check_region("Num", start, end)
 
     def test_integer_literals_and_sorted_children(self):
@@ -181,6 +175,12 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_region("BoolOp", 0, len(source) - 1)
         checker.check_children("BoolOp", [NameConstant, " ", "and", " ", NameConstant])
 
+    def test_matmult_node(self):
+        source = "a @ b\n"
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        checker.check_children("BinOp", ["Name", " ", "@", " ", "Name"])
+
     def test_basic_closing_parens(self):
         source = "1 + (2)\n"
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -1188,11 +1188,8 @@ class PatchedASTTest(unittest.TestCase):
         """)
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        node_to_test = "Try" if pycompat.PY3 else "TryFinally"
-        if pycompat.PY3:
-            expected_children = ["try", "", ":", "\n    ", "Pass", "\n", "finally", "", ":", "\n    ", "Pass"]
-        else:
-            expected_children = ["try", "", ":", "\n    ", "Pass", "\n", "finally", "", ":", "\n    ", "Pass"]
+        node_to_test = "Try"
+        expected_children = ["try", "", ":", "\n    ", "Pass", "\n", "finally", "", ":", "\n    ", "Pass"]
         checker.check_children(node_to_test, expected_children)
 
     @testutils.only_for_versions_lower("3")
@@ -1223,12 +1220,12 @@ class PatchedASTTest(unittest.TestCase):
         """)
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        node_to_test = "Try" if pycompat.PY3 else "TryExcept"
+        node_to_test = "Try"
         checker.check_children(
             node_to_test,
             ["try", "", ":", "\n    ", "Pass", "\n", ("excepthandler", "ExceptHandler")],
         )
-        expected_child = "e" if pycompat.PY3 else "Name"
+        expected_child = "e" 
         checker.check_children(
             ("excepthandler", "ExceptHandler"),
             ["except", " ", "Name", " ", "as", " ", expected_child, "", ":", "\n    ", "Pass"],
@@ -1246,11 +1243,8 @@ class PatchedASTTest(unittest.TestCase):
         """)
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        node_to_test = "Try" if pycompat.PY3 else "TryFinally"
-        if pycompat.PY3:
-            expected_children = ["try", "", ":", "\n    ", "Pass", "\n", "ExceptHandler", "\n", "finally", "", ":", "\n    ", "Pass"]
-        else:
-            expected_children = ["TryExcept", "\n", "finally", "", ":", "\n    ", "Pass"]
+        node_to_test = "Try"
+        expected_children = ["try", "", ":", "\n    ", "Pass", "\n", "ExceptHandler", "\n", "finally", "", ":", "\n    ", "Pass"]
         checker.check_children(node_to_test, expected_children)
 
     def test_ignoring_comments(self):
@@ -1561,7 +1555,7 @@ class PatchedASTTest(unittest.TestCase):
         ])
 
 
-class _ResultChecker(object):
+class _ResultChecker:
     def __init__(self, test_case, ast):
         self.test_case = test_case
         self.ast = ast
@@ -1577,7 +1571,7 @@ class _ResultChecker(object):
         if not isinstance(text, (tuple, list)):
             goal = [text]
 
-        class Search(object):
+        class Search:
             result = None
 
             def __call__(self, node):
