@@ -15,12 +15,12 @@ from ropetest import testutils
 
 class RenameRefactoringTest(unittest.TestCase):
     def setUp(self):
-        super(RenameRefactoringTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project()
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(RenameRefactoringTest, self).tearDown()
+        super().tearDown()
 
     def _local_rename(self, source_code, offset, new_name):
         testmod = testutils.create_module(self.project, "testmod")
@@ -263,18 +263,14 @@ class RenameRefactoringTest(unittest.TestCase):
     def test_rename_functions_parameters_and_occurences_in_other_modules(self):
         mod1 = testutils.create_module(self.project, "mod1")
         mod2 = testutils.create_module(self.project, "mod2")
-        mod1.write(
-            dedent("""\
-                def a_func(a_param):
-                    print(a_param)
-            """)
-        )
-        mod2.write(
-            dedent("""\
-                from mod1 import a_func
-                a_func(a_param=10)
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func(a_param):
+                print(a_param)
+        """))
+        mod2.write(dedent("""\
+            from mod1 import a_func
+            a_func(a_param=10)
+        """))
         self._rename(mod1, mod1.read().index("a_param") + 1, "new_param")
         self.assertEqual(
             dedent("""\
@@ -416,8 +412,7 @@ class RenameRefactoringTest(unittest.TestCase):
             dedent("""\
                 def new_func():
                     a_func=20
-                new_func()"""
-            ),
+                new_func()"""),
             refactored,
         )
 
@@ -448,8 +443,7 @@ class RenameRefactoringTest(unittest.TestCase):
             dedent("""\
                 async def new_func():
                     pass
-                new_func()"""
-            ),
+                new_func()"""),
             refactored,
         )
 
@@ -466,27 +460,22 @@ class RenameRefactoringTest(unittest.TestCase):
                 async def new_func():
                     pass
                 async def a_func():
-                    await new_func()"""
-            ),
+                    await new_func()"""),
             refactored,
         )
 
     def test_renaming_functions_across_modules(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-                a_func()
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+            a_func()
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                import mod1
-                mod1.a_func()
-            """)
-        )
+        mod2.write(dedent("""\
+            import mod1
+            mod1.a_func()
+        """))
         self._rename(mod1, len(mod1.read()) - 5, "new_func")
         self.assertEqual(
             dedent("""\
@@ -506,20 +495,16 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_renaming_functions_across_modules_from_import(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-                a_func()
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+            a_func()
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                from mod1 import a_func
-                a_func()
-            """)
-        )
+        mod2.write(dedent("""\
+            from mod1 import a_func
+            a_func()
+        """))
         self._rename(mod1, len(mod1.read()) - 5, "new_func")
         self.assertEqual(
             dedent("""\
@@ -539,20 +524,16 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_renaming_functions_from_another_module(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-                a_func()
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+            a_func()
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                import mod1
-                mod1.a_func()
-            """)
-        )
+        mod2.write(dedent("""\
+            import mod1
+            mod1.a_func()
+        """))
         self._rename(mod2, len(mod2.read()) - 5, "new_func")
         self.assertEqual(
             dedent("""\
@@ -572,20 +553,16 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_applying_all_changes_together(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                import mod2
-                mod2.a_func()
-            """)
-        )
+        mod1.write(dedent("""\
+            import mod2
+            mod2.a_func()
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                def a_func():
-                    pass
-                a_func()
-            """)
-        )
+        mod2.write(dedent("""\
+            def a_func():
+                pass
+            a_func()
+        """))
         self._rename(mod2, len(mod2.read()) - 5, "new_func")
         self.assertEqual(
             dedent("""\
@@ -605,12 +582,10 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_renaming_modules(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
         mod2.write("from mod1 import a_func\n")
         self._rename(mod2, mod2.read().index("mod1") + 1, "newmod")
@@ -621,19 +596,15 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_renaming_modules_aliased(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                import mod1 as m
-                m.a_func()
-            """)
-        )
+        mod2.write(dedent("""\
+            import mod1 as m
+            m.a_func()
+        """))
         self._rename(mod1, None, "newmod")
         self.assertTrue(
             not mod1.exists() and self.project.find_module("newmod") is not None
@@ -643,12 +614,10 @@ class RenameRefactoringTest(unittest.TestCase):
     def test_renaming_packages(self):
         pkg = testutils.create_package(self.project, "pkg")
         mod1 = testutils.create_module(self.project, "mod1", pkg)
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         mod2 = testutils.create_module(self.project, "mod2", pkg)
         mod2.write("from pkg.mod1 import a_func\n")
         self._rename(mod2, 6, "newpkg")
@@ -658,26 +627,20 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_module_dependencies(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                class AClass(object):
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            class AClass(object):
+                pass
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                import mod1
-                a_var = mod1.AClass()
-            """)
-        )
+        mod2.write(dedent("""\
+            import mod1
+            a_var = mod1.AClass()
+        """))
         self.project.get_pymodule(mod2).get_attributes()["mod1"]
-        mod1.write(
-            dedent("""\
-                def AClass():
-                    return 0
-            """)
-        )
+        mod1.write(dedent("""\
+            def AClass():
+                return 0
+        """))
 
         self._rename(mod2, len(mod2.read()) - 3, "a_func")
         self.assertEqual(
@@ -697,21 +660,16 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_renaming_class_attributes(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                class AClass(object):
-                    def __init__(self):
-                        self.an_attr = 10
-            """)
-        )
+        mod1.write(dedent("""\
+            class AClass(object):
+                def __init__(self):
+                    self.an_attr = 10
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                import mod1
-                a_var = mod1.AClass()
-                another_var = a_var.an_attr"""
-            )
-        )
+        mod2.write(dedent("""\
+            import mod1
+            a_var = mod1.AClass()
+            another_var = a_var.an_attr"""))
 
         self._rename(mod1, mod1.read().index("an_attr"), "attr")
         self.assertEqual(
@@ -726,29 +684,23 @@ class RenameRefactoringTest(unittest.TestCase):
             dedent("""\
                 import mod1
                 a_var = mod1.AClass()
-                another_var = a_var.attr"""
-            ),
-            mod2.read()
+                another_var = a_var.attr"""),
+            mod2.read(),
         )
 
     def test_renaming_class_attributes2(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                class AClass(object):
-                    def __init__(self):
-                        an_attr = 10
-                        self.an_attr = 10
-            """)
-        )
+        mod1.write(dedent("""\
+            class AClass(object):
+                def __init__(self):
+                    an_attr = 10
+                    self.an_attr = 10
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent("""\
-                import mod1
-                a_var = mod1.AClass()
-                another_var = a_var.an_attr"""
-            )
-        )
+        mod2.write(dedent("""\
+            import mod1
+            a_var = mod1.AClass()
+            another_var = a_var.an_attr"""))
 
         self._rename(mod1, mod1.read().rindex("an_attr"), "attr")
         self.assertEqual(
@@ -764,23 +716,20 @@ class RenameRefactoringTest(unittest.TestCase):
             dedent("""\
                 import mod1
                 a_var = mod1.AClass()
-                another_var = a_var.attr"""
-            ),
+                another_var = a_var.attr"""),
             mod2.read(),
         )
 
     def test_renaming_methods_in_subclasses(self):
         mod = testutils.create_module(self.project, "mod1")
-        mod.write(
-            dedent("""\
-                class A(object):
-                    def a_method(self):
-                        pass
-                class B(A):
-                    def a_method(self):
-                        pass
-            """)
-        )
+        mod.write(dedent("""\
+            class A(object):
+                def a_method(self):
+                    pass
+            class B(A):
+                def a_method(self):
+                    pass
+        """))
 
         self._rename(
             mod, mod.read().rindex("a_method") + 1, "new_method", in_hierarchy=True
@@ -799,19 +748,17 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_renaming_methods_in_sibling_classes(self):
         mod = testutils.create_module(self.project, "mod1")
-        mod.write(
-            dedent("""\
-                class A(object):
-                    def a_method(self):
-                        pass
-                class B(A):
-                    def a_method(self):
-                        pass
-                class C(A):
-                    def a_method(self):
-                        pass
-            """)
-        )
+        mod.write(dedent("""\
+            class A(object):
+                def a_method(self):
+                    pass
+            class B(A):
+                def a_method(self):
+                    pass
+            class C(A):
+                def a_method(self):
+                    pass
+        """))
 
         self._rename(
             mod, mod.read().rindex("a_method") + 1, "new_method", in_hierarchy=True
@@ -833,16 +780,14 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_not_renaming_methods_in_hierarchies(self):
         mod = testutils.create_module(self.project, "mod1")
-        mod.write(
-            dedent("""\
-                class A(object):
-                    def a_method(self):
-                        pass
-                class B(A):
-                    def a_method(self):
-                        pass
-            """)
-        )
+        mod.write(dedent("""\
+            class A(object):
+                def a_method(self):
+                    pass
+            class B(A):
+                def a_method(self):
+                    pass
+        """))
 
         self._rename(
             mod, mod.read().rindex("a_method") + 1, "new_method", in_hierarchy=False
@@ -861,13 +806,11 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_undoing_refactorings(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-                a_func()
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+            a_func()
+        """))
         self._rename(mod1, len(mod1.read()) - 5, "new_func")
         self.project.history.undo()
         self.assertEqual(
@@ -881,12 +824,10 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_undoing_renaming_modules(self):
         mod1 = testutils.create_module(self.project, "mod1")
-        mod1.write(
-            dedent("""\
-                def a_func():
-                    pass
-            """)
-        )
+        mod1.write(dedent("""\
+            def a_func():
+                pass
+        """))
         mod2 = testutils.create_module(self.project, "mod2")
         mod2.write("from mod1 import a_func\n")
         self._rename(mod2, 6, "newmod")
@@ -1036,8 +977,7 @@ class RenameRefactoringTest(unittest.TestCase):
                 def a_func(new_param):
                     print(new_param)
                 param=10
-                a_func(new_param=param)"""
-            ),
+                a_func(new_param=param)"""),
             refactored,
         )
 
@@ -1407,29 +1347,25 @@ class RenameRefactoringTest(unittest.TestCase):
         )
 
     def test_multi_byte_strs_and_renaming(self):
-        s = u"{LATIN SMALL LETTER I WITH DIAERESIS}" * 4
-        code = u"# -*- coding: utf-8 -*-\n# " + s + "\na = 1\nprint(2 + a + 2)\n"
+        s = "{LATIN SMALL LETTER I WITH DIAERESIS}" * 4
+        code = "# -*- coding: utf-8 -*-\n# " + s + "\na = 1\nprint(2 + a + 2)\n"
         refactored = self._local_rename(code, code.rindex("a"), "b")
         self.assertEqual(
-            u"# -*- coding: utf-8 -*-\n# " + s + "\nb = 1\nprint(2 + b + 2)\n",
+            "# -*- coding: utf-8 -*-\n# " + s + "\nb = 1\nprint(2 + b + 2)\n",
             refactored,
         )
 
     def test_resources_parameter(self):
         mod1 = testutils.create_module(self.project, "mod1")
         mod2 = testutils.create_module(self.project, "mod2")
-        mod1.write(
-            dedent("""\
-                def f():
-                    pass
-            """)
-        )
-        mod2.write(
-            dedent("""\
-                import mod1
-                mod1.f()
-            """)
-        )
+        mod1.write(dedent("""\
+            def f():
+                pass
+        """))
+        mod2.write(dedent("""\
+            import mod1
+            mod1.f()
+        """))
         self._rename(mod1, mod1.read().rindex("f"), "g", resources=[mod1])
         self.assertEqual(
             dedent("""\
@@ -1449,18 +1385,14 @@ class RenameRefactoringTest(unittest.TestCase):
     def test_resources_parameter_not_changing_defining_module(self):
         mod1 = testutils.create_module(self.project, "mod1")
         mod2 = testutils.create_module(self.project, "mod2")
-        mod1.write(
-            dedent("""\
-                def f():
-                    pass
-            """)
-        )
-        mod2.write(
-            dedent("""\
-                import mod1
-                mod1.f()
-            """)
-        )
+        mod1.write(dedent("""\
+            def f():
+                pass
+        """))
+        mod2.write(dedent("""\
+            import mod1
+            mod1.f()
+        """))
         self._rename(mod1, mod1.read().rindex("f"), "g", resources=[mod2])
         self.assertEqual(
             dedent("""\
@@ -1515,13 +1447,9 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1 = testutils.create_module(self.project, "utils", pkg)
 
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent(
-                """\
-                import json.utils as stdlib_json_utils
-            """
-            )
-        )
+        mod2.write(dedent("""\
+            import json.utils as stdlib_json_utils
+        """))
         self._rename(pkg, None, "new_json")
         self.assertTrue(
             not mod1.exists() and self.project.find_module("new_json.utils") is not None
@@ -1533,13 +1461,9 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1 = testutils.create_module(self.project, "utils", pkg)
 
         mod2 = testutils.create_module(self.project, "mod2")
-        mod2.write(
-            dedent(
-                """\
-                import json.utils.a as stdlib_json_utils
-            """
-            )
-        )
+        mod2.write(dedent("""\
+            import json.utils.a as stdlib_json_utils
+        """))
         self._rename(pkg, None, "new_json")
         self.assertTrue(
             not mod1.exists() and self.project.find_module("new_json.utils") is not None
@@ -1554,15 +1478,13 @@ class ChangeOccurrencesTest(unittest.TestCase):
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(ChangeOccurrencesTest, self).tearDown()
+        super().tearDown()
 
     def test_simple_case(self):
-        self.mod.write(
-            dedent("""\
-                a_var = 1
-                print(a_var)
-            """)
-        )
+        self.mod.write(dedent("""\
+            a_var = 1
+            print(a_var)
+        """))
         changer = rename.ChangeOccurrences(
             self.project, self.mod, self.mod.read().index("a_var")
         )
@@ -1576,14 +1498,12 @@ class ChangeOccurrencesTest(unittest.TestCase):
         )
 
     def test_only_performing_inside_scopes(self):
-        self.mod.write(
-            dedent("""\
-                a_var = 1
-                new_var = 2
-                def f():
-                    print(a_var)
-            """)
-        )
+        self.mod.write(dedent("""\
+            a_var = 1
+            new_var = 2
+            def f():
+                print(a_var)
+        """))
         changer = rename.ChangeOccurrences(
             self.project, self.mod, self.mod.read().rindex("a_var")
         )
@@ -1599,16 +1519,14 @@ class ChangeOccurrencesTest(unittest.TestCase):
         )
 
     def test_only_performing_on_calls(self):
-        self.mod.write(
-            dedent("""\
-                def f1():
-                    pass
-                def f2():
-                    pass
-                g = f1
-                a = f1()
-            """)
-        )
+        self.mod.write(dedent("""\
+            def f1():
+                pass
+            def f2():
+                pass
+            g = f1
+            a = f1()
+        """))
         changer = rename.ChangeOccurrences(
             self.project, self.mod, self.mod.read().rindex("f1")
         )
@@ -1626,13 +1544,11 @@ class ChangeOccurrencesTest(unittest.TestCase):
         )
 
     def test_only_performing_on_reads(self):
-        self.mod.write(
-            dedent("""\
-                a = 1
-                b = 2
-                print(a)
-            """)
-        )
+        self.mod.write(dedent("""\
+            a = 1
+            b = 2
+            print(a)
+        """))
         changer = rename.ChangeOccurrences(
             self.project, self.mod, self.mod.read().rindex("a")
         )
@@ -1649,7 +1565,7 @@ class ChangeOccurrencesTest(unittest.TestCase):
 
 class ImplicitInterfacesTest(unittest.TestCase):
     def setUp(self):
-        super(ImplicitInterfacesTest, self).setUp()
+        super().setUp()
         self.project = testutils.sample_project(validate_objectdb=True)
         self.pycore = self.project.pycore
         self.mod1 = testutils.create_module(self.project, "mod1")
@@ -1657,7 +1573,7 @@ class ImplicitInterfacesTest(unittest.TestCase):
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(ImplicitInterfacesTest, self).tearDown()
+        super().tearDown()
 
     def _rename(self, resource, offset, new_name, **kwds):
         changes = Rename(self.project, resource, offset).get_changes(new_name, **kwds)
@@ -1665,21 +1581,19 @@ class ImplicitInterfacesTest(unittest.TestCase):
 
     def test_performing_rename_on_parameters(self):
         self.mod1.write("def f(arg):\n    arg.run()\n")
-        self.mod2.write(
-            dedent("""\
-                import mod1
+        self.mod2.write(dedent("""\
+            import mod1
 
 
-                class A(object):
-                    def run(self):
-                        pass
-                class B(object):
-                    def run(self):
-                        pass
-                mod1.f(A())
-                mod1.f(B())
-            """)
-        )
+            class A(object):
+                def run(self):
+                    pass
+            class B(object):
+                def run(self):
+                    pass
+            mod1.f(A())
+            mod1.f(B())
+        """))
         self.pycore.analyze_module(self.mod2)
         self._rename(self.mod1, self.mod1.read().index("run"), "newrun")
         self.assertEqual("def f(arg):\n    arg.newrun()\n", self.mod1.read())
